@@ -73,7 +73,7 @@ end
 Facter.add("virtual") do
   confine :kernel => 'SunOS'
   has_weight 10
-  self.timeout = 6
+  self.timeout = 20
 
   setcode do
     next "zone" if Facter::Util::Virtual.zone?
@@ -149,7 +149,7 @@ Facter.add("virtual") do
       next "xenhvm"     if lines.any? {|l| l =~ /XenSource/ }
       next "hyperv"     if lines.any? {|l| l =~ /Microsoft Corporation Hyper-V/ }
       next "gce"        if lines.any? {|l| l =~ /Class 8007: Google, Inc/ }
-      next "kvm"        if lines.any? {|l| l =~ /virtio/ }
+      next "kvm"        if lines.any? {|l| l =~ /virtio/i }
     end
 
     # Parse dmidecode
@@ -164,6 +164,7 @@ Facter.add("virtual") do
       next "rhev"       if lines.any? {|l| l =~ /Product Name: RHEV Hypervisor/ }
       next "ovirt"      if lines.any? {|l| l =~ /Product Name: oVirt Node/ }
       next "bochs"      if lines.any? {|l| l =~ /Bochs/ }
+      next "kvm"        if lines.any? {|l| l =~ /Manufacturer: QEMU/ }
     end
 
     # Default to 'physical'
